@@ -1,6 +1,7 @@
 ''' Schemdraw Drawing class '''
 
 from collections import namedtuple
+from enum import Enum, unique
 import warnings
 import numpy as np
 
@@ -11,6 +12,21 @@ from .backends.mpl import Figure
 BBox = namedtuple('BBox', ['xmin', 'ymin', 'xmax', 'ymax'])
 
 
+@unique
+class ImageFormat(str, Enum):
+    ''' Known Matplotlib image formats '''
+    EPS = 'eps'
+    JPG = 'jpg'    
+    PDF = 'pdf'
+    PGF = 'pgf'
+    PNG = 'png'
+    PS = 'ps'
+    RAW = 'raw'
+    RGBA = 'rgba'
+    SVG = 'svg'
+    TIF = 'tif'
+
+
 class Drawing(object):
     ''' Create a schematic drawing
 
@@ -37,9 +53,18 @@ class Drawing(object):
             Default line style '-', ':', '--', etc.
         fill : string or tuple
             Deault fill color for closed elements
+            
+        Attributes
+        ----------
+        here : xy tuple
+            Current drawing position. The next element will be added
+            at this position unless specified otherwise.
+        theta : float
+            Current drawing angle, in degrees. The next element will
+            be added with this angle unless specified otherwise.
     '''
     def __init__(self, *elements, unit=3.0, inches_per_unit=0.5, lblofst=0.1,
-                 fontsize=16, font='sans-serif', color='black',
+                 fontsize=14, font='sans-serif', color='black',
                  lw=2, ls='-', fill=None):
         self.elements = []
         self.inches_per_unit = inches_per_unit
@@ -84,7 +109,7 @@ class Drawing(object):
 
     def _repr_svg_(self):
         ''' SVG representation for Jupyter '''
-        return self.draw().getimage('svg')
+        return self.draw().getimage('svg').decode()
 
     def _repr_png_(self):
         ''' PNG representation for Jupyter '''
@@ -208,20 +233,28 @@ class Drawing(object):
         self.add(element)
         return element
 
-    def draw(self, showframe=False):
+    def draw(self, showframe=False, show=True):
         ''' Draw the schematic
 
             Parameters
             ----------
             showframe : bool
                 Show axis frame. Useful for debugging a drawing.
+            show : bool
+                Show the schematic in a GUI popup window (when
+                 outside of a Jupyter inline environment)
+
+            Returns
+            -------
+            schemdraw Figure object
         '''
         fig = Figure(bbox=self.get_bbox(),
                      inches_per_unit=self.inches_per_unit,
                      showframe=showframe)
         for element in self.elements:
             element.draw(fig)
-        fig.show()  # Show figure in window if not inline/Jupyter mode
+        if show:
+            fig.show()  # Show figure in window if not inline/Jupyter mode
         return fig  # Otherwise return Figure and let _repr_ display it
 
     def save(self, fname, transparent=True, dpi=72):
@@ -237,5 +270,21 @@ class Drawing(object):
             dpi : float
                 Dots-per-inch for raster formats
         '''
-        fig = self.draw()
+        fig = self.draw(show=False)
         fig.save(fname, transparent=transparent, dpi=dpi)
+
+    def get_imagedata(self, fmt: ImageFormat):
+        ''' Get image data as bytes array
+
+            Parameters
+            ----------
+            fmt : ImageFormat
+                Format or file extension of the image type
+
+            Returns
+            -------
+            img : bytes array
+                Image data
+        '''
+        fig = self.draw(show=False)
+        return fig.getimage(ext=fmt)
\ No newline at end of file
